@@ -30,9 +30,11 @@ ABSTRACT_DATETIME = 3
 CONTACT = 4
 DURATION = 5
 PREDECESSOR_LIST = 6
-NUMBER = 7
-BOOLEAN = 8
-STRING = 9
+MULTI_CONTACT = 7
+MULTI_PICKLIST = 8
+NUMBER = 9
+BOOLEAN = 10
+STRING = 11
 
 OBJECT_VALUE = {
     'object_type': [
@@ -41,7 +43,10 @@ OBJECT_VALUE = {
         'ABSTRACT_DATETIME',
         'CONTACT',
         'DURATION',
-        'PREDECESSOR_LIST']}
+        'PREDECESSOR_LIST',
+        'MULTI_CONTACT',
+        'MULTI_PICKLIST'
+    ]}
 
 _typeToName = {
     DATE: 'DATE',
@@ -50,6 +55,8 @@ _typeToName = {
     CONTACT: 'CONTACT',
     DURATION: 'DURATION',
     PREDECESSOR_LIST: 'PREDECESSOR_LIST',
+    MULTI_CONTACT: 'MULTI_CONTACT',
+    MULTI_PICKLIST: 'MULTI_PICKLIST'
 }
 
 _nameToType = {
@@ -59,6 +66,8 @@ _nameToType = {
     'CONTACT': CONTACT,
     'DURATION': DURATION,
     'PREDECESSOR_LIST': PREDECESSOR_LIST,
+    'MULTI_CONTACT': MULTI_CONTACT,
+    'MULTI_PICKLIST': MULTI_PICKLIST
 }
 
 
